OC.L10N.register(
    "files",
    {
    "File could not be found" : "Фајл није нађен",
    "Move or copy" : "Помери или копирај",
    "Download" : "Преузми",
    "Delete" : "Обриши",
    "Tags" : "Ознаке",
    "Show list view" : "Prikaži prikaz liste",
    "Show grid view" : "Prikaži prikaz mreže",
    "Home" : "Почетна",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Не могу да направим фасциклу „{dir}“",
    "This will stop your current uploads." : "Ово ће да прекине тренутна отпремања.",
    "Upload cancelled." : "Отпремање је отказано.",
    "Processing files …" : "Обрађујем фајлове…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то или директоријум или има 0 бајтова",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
    "Target folder \"{dir}\" does not exist any more" : "Одредишна фасцикла „{dir}“ више не постоји",
    "Not enough free space" : "Нема довољно слободног места",
    "An unknown error has occurred" : "Десила се непозната грешка",
    "File could not be uploaded" : "Фајл не може да се отпреми",
    "Uploading …" : "Отпремам…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Отпремање … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Отпремање те ставке није подржано",
    "Target folder does not exist any more" : "Одредишна фасцикла више не постоји",
    "Operation is blocked by access control" : "Контрола приступа је блокирала операцију",
    "Error when assembling chunks, status code {status}" : "Грешки при прикупљању делова фајла, статус код {status}",
    "Actions" : "Радње",
    "Rename" : "Преименуј",
    "Move" : "Помери",
    "Copy" : "Копирај",
    "Choose target folder" : "Одаберите одредишну фасциклу",
    "Set reminder" : "Постави подсетник",
    "Edit locally" : "Уреди локално",
    "Open" : "Отвори",
    "_Delete file_::_Delete files_" : ["Обриши фајл","Обриши фајлове","Обриши фајлове"],
    "_Delete folder_::_Delete folders_" : ["Обрши фолдер","Обриши фолдере","Обриши фолдере"],
    "_Disconnect storage_::_Disconnect storages_" : ["Искључи складиште","Искључи складишта","Искључи складишта"],
    "_Leave this share_::_Leave these shares_" : ["Напусти ово дељење","Напусти ова дељења","Напусти ова дељења"],
    "Could not load info for file \"{file}\"" : "Не могу да учитам информације фајла „{file}“",
    "Files" : "Фајлови",
    "Details" : "Детаљи",
    "Please select tag(s) to add to the selection" : "Молимо вас да изаберете ознаку (или више њих) која треба да се дода избору",
    "Apply tag(s) to selection" : "Примени ознаку (или више њих) на избор",
    "Select directory \"{dirName}\"" : "Избор директоријума „{dirName}",
    "Select file \"{fileName}\"" : "Избор фајла „{fileName}”",
    "Pending" : "На чекању",
    "Unable to determine date" : "Не могу да одредим датум",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите дневник или контактирајте администратора",
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Could not move \"{file}\", target exists" : "Не могу да преместим „{file}“. Одредиште већ постоји",
    "Could not move \"{file}\"" : "Не могу да преместим „{file}“",
    "copy" : "копиран",
    "Could not copy \"{file}\", target exists" : "Не могу да копирам „{file}“, одредиште већ постоји",
    "Could not copy \"{file}\"" : "Не могу да копирам „{file}“",
    "Copied {origin} inside {destination}" : "Копиран {origin} у {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копиран{origin} и још {nbfiles} других фајлова у {destination}",
    "Failed to redirect to client" : "Преусмеравање на клијента није успело",
    "{newName} already exists" : "{newName} већ постоји",
    "Could not rename \"{fileName}\", it does not exist any more" : "Не могу да преименујем „{fileName}“. Фајл више не постоји",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{targetName}“ се већ користи у фасцикли „{dir}“. Одаберите неко друго име.",
    "Could not rename \"{fileName}\"" : "Не могу да преименујем „{fileName}“",
    "Could not create file \"{file}\"" : "Не могу да направим фајл „{file}“",
    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл „{file}“ јер већ постоји",
    "Could not create folder \"{dir}\" because it already exists" : "Не могу да направим фасциклу „{dir}“ јер већ постоји",
    "Could not fetch file details \"{file}\"" : "Не могу да дохватим детаље за „{file}“",
    "Error deleting file \"{fileName}\"." : "Грешка при брисању фајла „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Унесите више од два карактера да претражујете у другим фасциклама",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["укључујући и %n скривени","укључујући и %n скривена","укључујући и %n скривених"],
    "You do not have permission to upload or create files here" : "Немате дозволу да овде отпреминте или креирате фајлове",
    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
    "New" : "Нов",
    "New file/folder menu" : "Мени за нови фајл/фолдер",
    "Select file range" : "Одаберите опсег фајлова",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "{used} од {quota} искоришћено",
    "{used} used" : "{used} искоришћено",
    "\"{name}\" is an invalid file name." : "„{name}“ није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"/\" is not allowed inside a file name." : "„/“ није дозвољен каракетер у имену фајла.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ није дозвољени тип фајла",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Складиште власника {owner} је пуно, више није могуће отпремање или синхронизација фајлова!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Групни фолдер „{mountPoint}” је пун, фајлови више не могу да се ажурирају или синхронизују!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Спаљно складиште „{mountPoint}” је пуно, фајлови више не могу да се ажурирају или синхронизују!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Ваше складиште је пуно, фајлови випе не могу да се ажурирају или синхронизују!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Групна фасцикла „{mountPoint}“ је скоро пуна ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Спољашње складиште „{mountPoint}“ је скоро пуно ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Ваше складиште је скоро пуно ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["се подудара са „{filter}”","се подударају са „{filter}","се подудара са „{filter}"],
    "View in folder" : "Види у фасцикли",
    "Direct link was copied (only works for people who have access to this file/folder)" : "Копиран је директан линк (функционише само за особе који имају приступ овом фајлу/фолдеру)",
    "Path" : "Путања",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
    "Favorited" : "Омиљено",
    "Favorite" : "Омиљено",
    "Copy direct link (only works for people who have access to this file/folder)" : "Копирај директни линк (ради само за особе које имају приступ овом фајлу/фолдеру)",
    "New folder" : "Нова фасцикла",
    "Create new folder" : "Направи нову фасциклу",
    "Upload file" : "Отпреми фајл",
    "Recent" : "Скорашњи",
    "Not favorited" : "Није омиљено",
    "Remove from favorites" : "Избаци из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
    "Added to favorites" : "Додато у омиљено",
    "Removed from favorites" : "Избачено из омиљених",
    "You added {file} to your favorites" : "Додали сте {file} у омиљене",
    "You removed {file} from your favorites" : "Избацили сте {file} из омиљених",
    "Favorites" : "Омиљени",
    "File changes" : "Измене над фајлом",
    "Created by {user}" : "Направио {user}",
    "Changed by {user}" : "Изменио {user}",
    "Deleted by {user}" : "Обрисао {user}",
    "Restored by {user}" : "Повратио {user}",
    "Renamed by {user}" : "Преименовао {user}",
    "Moved by {user}" : "Померио {user}",
    "\"remote account\"" : "„удаљени налог”",
    "You created {file}" : "Направили сте {file}",
    "You created an encrypted file in {file}" : "Направили сте шифровани фајл {file}",
    "{user} created {file}" : "{user} је направио {file}",
    "{user} created an encrypted file in {file}" : "{user} је направио шифровани фајл {file}",
    "{file} was created in a public folder" : "{file} је направљен у јавној фасцикли",
    "You changed {file}" : "Изменили сте {file}",
    "You changed an encrypted file in {file}" : "Изменили сте шифровани фајл {file}",
    "{user} changed {file}" : "{user} је изменио {file}",
    "{user} changed an encrypted file in {file}" : "{user} је изменио шифровани фајл {file}",
    "You deleted {file}" : "Обрисали сте {file}",
    "You deleted an encrypted file in {file}" : "Обрисали сте шифровани фајл {file}",
    "{user} deleted {file}" : "{user} је обрисао {file}",
    "{user} deleted an encrypted file in {file}" : "{user} је обрисао шифровани фајл {file}",
    "You restored {file}" : "Повратили сте {file}",
    "{user} restored {file}" : "{user} је повратио {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Променили сте име фајла {oldfile} (скривено) на {newfile} (скривено)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Променили сте име фајла {oldfile} (скривено) на {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Променили сте име фајла {oldfile} на {newfile} (скривено)",
    "You renamed {oldfile} to {newfile}" : "Преименовали сте {oldfile} на {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} је променио име фајла {oldfile} (скривено) на {newfile} (скривено)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} је променио име фајла {oldfile} (скривено) на {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} је променио име фајла {oldfile} на {newfile} (скривено)",
    "{user} renamed {oldfile} to {newfile}" : "{user} је преименовао {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Померили сте {oldfile} на {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} је померио {oldfile} на {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Фајл је додат или избрисан из Ваших <strong>омиљених</strong>",
    "A file or folder has been <strong>changed</strong>" : "Фајл или фасцикла су <strong>измењени</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Омиљени фајл или фасцикла су <strong>измењени</strong>",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "Accept" : "Прихвати",
    "Reject" : "Одбаци",
    "Incoming ownership transfer from {user}" : "Надолазећи пренос власништва од корисника {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Да ли желите да прихватите {path}?\n\nПажња: После прихватања, процес трансфера може потрајати и до 1h.",
    "Ownership transfer failed" : "Пренос власништва није успео",
    "Your ownership transfer of {path} to {user} failed." : "Ваш пренос власништва {path} на корисника {user} није успео.",
    "The ownership transfer of {path} from {user} failed." : "Пренос власништва {path} на корисника {user} није успео.",
    "Ownership transfer done" : "Пренос власништва завршен",
    "Your ownership transfer of {path} to {user} has completed." : "Ваш пренос власништва {path} на корисника {user} завршен.",
    "The ownership transfer of {path} from {user} has completed." : "Пренос власништва {path} на корисника {user} завршен.",
    "in %s" : "за %s",
    "File Management" : "Управљање фајловима",
    "Current directory path" : "Путања текућег директоријума",
    "Reload current directory" : "Поново учитај текући директоријум",
    "Go to the \"{dir}\" directory" : "Иди у „{dir}” дирекотријум",
    "Drag and drop files here to upload" : "Да отпремите, превуците и отпустите фајлове овде",
    "Your have used your space quota and cannot upload files anymore" : "Искористили сте квоту простора и више не можете да отпремате фајлове",
    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
    "Some files could not be uploaded" : "Неки фајлови нису могли да се отпреме",
    "Files uploaded successfully" : "Фајлови су успешно отремљени",
    "\"{displayName}\" action executed successfully" : "Акција „{displayName}” је успешно извршена",
    "\"{displayName}\" action failed" : "Акција „{displayName}” није успела",
    "Toggle selection for file \"{displayName}\"" : "Укљ./искљ. избор за фајл „{displayName}”",
    "Toggle selection for folder \"{displayName}\"" : "Укљ./искљ. избор за фолдер „{displayName}”",
    "Rename file" : "Промени назив фајла",
    "File name" : "Име фајла",
    "Folder name" : "Назив фасцикле",
    "This node is unavailable" : "Овај чвор није доступан",
    "Download file {name}" : "Преузми фајл {name}",
    "\"{name}\" is not an allowed filetype." : "„{name}” није дозвољени тип фајла.",
    "{newName} already exists." : "{newName} већ постоји.",
    "\"{char}\" is not allowed inside a file name." : "„{char}“ није дозвољен каракетер у имену фајла.",
    "Name cannot be empty" : "Назив не може бити празан",
    "Another entry with the same name already exists" : "Већ постоји ставка са истим именом.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "„{oldName}” је промењено на „{newName}”",
    "Could not rename \"{oldName}\", it does not exist any more" : "Не може да се промени име фајла „{fileName}” јер фајл више не постоји",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Назив „{targetName}” се већ користи у директоријуму „{dir}”. Молимо вас да изаберете неко друго име.",
    "Could not rename \"{oldName}\"" : "Не може да се промени име фајла „{fileName}”",
    "Total rows summary" : "Резиме укупног броја редова",
    "Toggle selection for all files and folders" : "Укљ./искљ. избор за све фајлове и фолдере",
    "\"{displayName}\" failed on some elements " : "„{displayName}” није успело на неким елементима",
    "\"{displayName}\" batch action executed successfully" : "Пакетна акција „{displayName}” се успешно извршила",
    "List of files and folders." : "Листа фајлова и фолдера.",
    "Column headers with buttons are sortable." : "Заглавља колона са дугмићима могу да се соритрају.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
    "File not found" : "Фајл није нађен",
    "Storage informations" : "Информације о складишту`",
    "{usedQuotaByte} used" : "{usedQuotaByte} искоришћено",
    "{relative}% used" : "{relative}% искоришћено",
    "Could not refresh storage stats" : "Статистике складишта нису могле да се освеже",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Create" : "Направи",
    "A file or folder with that name already exists." : "Фајл или фолдер са тим именом већ постоји.",
    "Transfer ownership of a file or folder" : "Пренеси власништво фајла или фасцикле",
    "Choose file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
    "Change" : "Измени",
    "New owner" : "Нови власник",
    "Choose a file or folder to transfer" : "Одаберите фајл или фасциклу за пренос",
    "Transfer" : "Пренеси",
    "Transfer {path} to {userid}" : "Пренеси {path} на корисника {userid}",
    "Invalid path selected" : "Одабрана неисправна путања",
    "Unknown error" : "Непозната грешка",
    "Ownership transfer request sent" : "Послат захтев за пренос власништва",
    "Cannot transfer ownership of a file or folder you do not own" : "Не можете да пренесете власништво над фајлом или фолдером који не поседујете",
    "Select file or folder to link to" : "Изаберите фајл или фолдер на који показује линк",
    "Choose file" : "Изаберите фајл",
    "Choose {file}" : "Изабери {file}",
    "Loading current folder" : "Учитавање текућег фолдера",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "Go to the previous folder" : "Иди на претходни фолдер",
    "Go back" : "Иди назад",
    "Share" : "Пдели",
    "Shared by link" : "Дељени путем везе",
    "Shared" : "Подељено",
    "Switch to list view" : "Пређи на поглед листе",
    "Switch to grid view" : "Пређи на поглед мреже",
    "Error during upload: {message}" : "Грешка при отпремању: {message}",
    "Error during upload, status code {status}" : "Грешка приликом отпремања, кôд статуса {status}",
    "Unknown error during upload" : "Непозната грешка током отпремања",
    "Open the files app settings" : "Отвори подешавања апликације фајлови",
    "Files settings" : "Подешавања фајлова",
    "File cannot be accessed" : "Фајлу не може да се приступи",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Фајл није могао да се пронађе или немате дозволу да га прегледате. Замолите пошиљаоца да га подели.",
    "Sort favorites first" : "Сортирај прво омиљене",
    "Sort folders before files" : "Поређај фолдере испред фајлова",
    "Show hidden files" : "Прикажи скривене фајлове",
    "Crop image previews" : "Опсецање прегледа слика",
    "Enable the grid view" : "Укључи приказ мреже",
    "Additional settings" : "Додатне поставке",
    "WebDAV" : "ВебДАВ",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Копирај у оставу",
    "Use this address to access your Files via WebDAV" : "Користи ову адресу да приступате Вашим фајловима преко ВебДАВа",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ако сте укључили 2FA, морате кликом овде да крерате нову лозинку апликације.",
    "Clipboard is not available" : "Клипборд није доступан",
    "WebDAV URL copied to clipboard" : "WebDAV URL је копиран у клипборд",
    "Unable to change the favourite state of the file" : "Неуспела промена стања омиљености фајла",
    "Error while loading the file data" : "Грешка при учитавању података фајла",
    "Pick a template for {name}" : "Изаберите шаблон за {name}",
    "Create a new file with the selected template" : "Креирање новог фајла по изабраном шаблону",
    "Creating file" : "Креирање фајла",
    "Blank" : "Празно",
    "Unable to create new file from template" : "Из шаблона није могао да се креира нови фајл",
    "Delete permanently" : "Обриши заувек",
    "Delete and unshare" : "Обриши и прекини дељење",
    "You are about to delete {count} items." : "Управо ћете обрисати {count} ставки.",
    "Confirm deletion" : "Потврди брисање",
    "Cancel" : "Поништи",
    "Deletion cancelled" : "Брисање је отказано",
    "Destination is not a folder" : "Одредиште није фолдер",
    "This file/folder is already in that directory" : "Овај фајл/фолдер се већ налази у том директоријуму",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Фајл/фолдер не можете да преместите у самог себе или у његов подфолдер",
    "(copy)" : "(копиран)",
    "(copy %n)" : "(копирано %n)",
    "Move cancelled" : "Премештање је отказано",
    "A file or folder with that name already exists in this folder" : "У овом фолдеру већ постоји фајл или фолдер са тим именом",
    "The file does not exist anymore" : "Фајл више не постоји",
    "Choose destination" : "Изаберите одредиште",
    "Copy to {target}" : "Копирај у {target}",
    "Move to {target}" : "Премести у {target}",
    "Cancelled move or copy operation" : "Операција премештања или копирања је отказана",
    "Move or copy operation failed" : "Није успела операција премештања или копирања",
    "Open folder {displayName}" : "Отвори фолдер {displayName}",
    "Open in Files" : "Отвори у Фајловима",
    "Open details" : "Отвори детаље",
    "An error occurred while uploading. Please try again later." : "Дошло је до грешке током отпремања Покушајте поново касније.",
    "Could not copy {file}. {message}" : "{file} не може да се копира. {message}",
    "Could not move {file}. {message}" : "{file} не може да се премести. {message}",
    "Created new folder \"{name}\"" : "Креиран је нови фолдер „{name}”",
    "Filename" : "Назив фајла",
    "Unable to initialize the templates directory" : "Фолдер са шаблонима није могао да се иницијализује",
    "Create new templates folder" : "Креирај нови фолдер шаблона",
    "Templates" : "Шаблони",
    "New template folder" : "Нови фолдер шаблона",
    "One of the dropped files could not be processed" : "Један од упуштених фајлова не може да се обради",
    "Uploading \"{filename}\" failed" : "Није успело отпремање „{filename}”",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} фолдер","{folderCount} фолдера","{folderCount} фолдера"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} фајл","{fileCount} фајла","{fileCount} фајлова"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 фајл и {folderCount} фолдер","1 фајл и {folderCount} фолдера","1 фајл и {folderCount} фолдера"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} фајл и 1 фолдер","{fileCount} фајла и 1 фолдер","{fileCount} фајлова и 1 фолдер"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} фајлова и {folderCount} фолдера",
    "List of favorites files and folders." : "Листа омиљених фајлова и директоријума.",
    "No favorites yet" : "Још нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
    "All files" : "Сви фајлови",
    "List of your files and folders." : "Листа ваших фајлова и фолдера.",
    "Personal Files" : "Лични фајлови",
    "List of your files and folders that are not shared." : "Листа ваших фајлова и фолдера који се не деле.",
    "No personal files found" : "Није пронађен ниједан лични фајл",
    "Files that are not shared will show up here." : "Овде ће се појавити фајлови који се не деле.",
    "List of recently modified files and folders." : "Листа фајлова и директоријума који су недавно измењени.",
    "No recently modified files" : "Нема недавно промењених фајлова",
    "Files and folders you recently modified will show up here." : "Овде ће се појавити фајлови и фолдери које сте недавно изменили.",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Отпремање је превелико",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "Text file" : "Tекстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Копиран је директан линк (функционише само за кориснике који имају приступ овом фајлу/фолдеру)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директну везу (ради само за кориснике који имају приступ овом фајлу/фасциклу)",
    "You can only favorite a single file or folder at a time" : "Можете поставити као омиљени само један фајл или фасциклу одједном",
    "\"remote user\"" : "„удаљени корисник“",
    "Search users" : "Претражи кориснике",
    "You might not have have permissions to view it, ask the sender to share it" : "Можда немате дозволе да га погледате, затражите од пошиљаоца да га подели са вама",
    "Set up templates folder" : "Постављање фолдера са шаблонима",
    "Toggle %1$s sublist" : "Укљ./искљ. %1$s подлисте",
    "Toggle grid view" : "Укључи/искључи приказ мреже",
    "Deleted files" : "Обрисани фајлови",
    "Shares" : "Дељења",
    "Shared with others" : "Дељени са осталима",
    "Shared with you" : "Дељени са вама",
    "Deleted shares" : "Обрисана дељења",
    "Pending shares" : "Дељења на чекању",
    "This file has the tag {tag}" : "Овај фајл има ознаку {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Овај фајл има ознаке {firstTags} и {lastTag}",
    "Select the row for {displayName}" : "Изабери ред за {displayName}",
    "Open folder {name}" : "Отвори фолдер {name}",
    "Unselect all" : "Поништи цео избор",
    "ascending" : "растуће",
    "descending" : "опадајуће",
    "Sort list by {column} ({direction})" : "Поређај листу по {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Ова листа није у потпуности приказана из разлога перформанси. Фајлови ће се приказивати како се крећете кроз листу.",
    "Search for an account" : "Претражите налог",
    "Choose" : "Изаберите",
    "No files or folders have been deleted yet" : "Још увек није обрисан ниједан фајл или фолдер",
    "Add" : "Додај",
    "The files is locked" : "Фајл је закључан"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
